# ------------------------------------------------------------------------------------------------------------
# Script to install on user login process the 'GoToMeeting Outlook Plugin' as silent installation
# This script aboard if the plugin is installed
#    or one of the prerequisites are not fulfilled
# ------------------------------------------------------------------------------------------------------------

$Plugin = $null
$OldPlugin = $null
$Outlook = $null
$DotNet = $null
$VSTOInstaller = $null
$VSTOInstallerPath = $null

# The source where we have to install our plugin from
$PluginPath = "https://builds.citrixonlinecdn.com/builds/calendarintegration/outlook/G2M/GoToMeetingOutlookCalendarPlugin.vsto"

Write-Output "Test if 'GoToMeeting Outlook Plugin' is installed for this user"
# READ the registry value where the plugin comes from
$Plugin = Get-Item -Path "HKCU:\Software\Microsoft\Office\Outlook\Addins\GoToMeetingOutlookCalendarPlugin" 2> $null
if( $Plugin -eq $null )
{
    # Plugin is not installed - test the prerequisites ...
    $PreReq = $true

    # Get the LogMeIn certificates from Trusted Publisher stores whitch are valid
    $LogMeInCerts = Get-Item @("Cert:\LocalMachine\TrustedPublisher\*"; "Cert:\CurrentUser\TrustedPublisher\*" ) | ForEach-Object {if($_.Subject -match "LogMeIn" -and $_.NotAfter -gt (Get-Date)) {$_} }
    if( $LogMeInCerts -eq $null -or $LogMeinCerts.Count -eq 0 )
    {
        $PreReq = $false
        Write-Error "Check Requirements: A valid LogMeIn Online certificate was not available in trusted publisher store"
    }

    # Test if outlook is available (We test for reg keys Outlook use to handle add-ins)
    $Outlook = Get-ItemProperty -Path "HKLM:\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\OUTLOOK.EXE" 2> $null
    if( $Outlook -eq $null )
    {
        $PreReq = $false
        Write-Error "Check Requirements: Outlook is not available on this machine"
    } else {
        # Check the Version of Outlook
        $OutlookVersion = (Get-Item $Outlook.'(default)').VersionInfo.ProductVersion
        Write-Output "Installed Outlook Version is: $OutlookVersion"
        if( -not $OutlookVersion -match "^(14|15|16).")
        { 
            $PreReq = $false
            Write-Error "Check Requirements: Outlook has wrong version - suported are only 14, 15 and 16"
        }
    }

    # Test if the required .Net Framework is installed
    $DotNet = Get-Item -Path @("HKLM:\SOFTWARE\Microsoft\NET Framework Setup\NDP\v4"; "HKLM:\SOFTWARE\Microsoft\NET Framework Setup\NDP\v4.0") 2> $null
    if( $DotNet -eq $null -or $DotNet.Count -le 0)
    {
        $PreReq = $false
        Write-Error "Check Requirements: We miss the .Net 4 Framework on this machine"
    }

    # Test if we have the required VSTO installer - The delivered Registry path has to contain \V4 in other case it's the wrong version
    $VSTOInstaller = Get-Item -Path @(
        "HKLM:\SOFTWARE\Wow6432Node\Microsoft\VSTO Runtime Setup\v4";
        "HKLM:\SOFTWARE\Wow6432Node\Microsoft\VSTO Runtime Setup\v4R"; 
        "HKLM:\SOFTWARE\Microsoft\VSTO Runtime Setup\v4"
        "HKLM:\SOFTWARE\Microsoft\VSTO Runtime Setup\v4R"
        ) 2> $null
    if( $VSTOInstaller -eq $null)
    {
        $PreReq = $false
        Write-Error "Check Requirements: We miss the .Net 4 Framework on this machine"
    }

    # Start installation if prerequisits are fulfilled
    if( $PreReq ) 
    {
        $VSTOInstaller | ForEach-Object { if( $_.GetValue("InstallerPath") -ne $null ) { $VSTOInstallerPath = $_.GetValue("InstallerPath") } } 
        # Now start the installation !!
        if( (Start-Process -FilePath $VSTOInstallerPath -ArgumentList  @("/install"; $PluginPath; "/silent") -Wait -Passthru).ExitCode -eq 0 )
        {
            Write-Output "Install Plugin: Installation was successfull"
        } else {
            Write-Error "Install Plugin: Installation was not successfull - Please check the Windows Application log"
        }
    }
} else {
    # Here we have possibility to test is the location is correct
    Write-Host "Plugin is installed from localtion:" $Plugin.GetValue("Manifest")
    # Make sure that the old GoToMeeting Outlook plugin is not started
    $OldPlugin = Get-ItemProperty "HKCU:\Software\Microsoft\Office\Outlook\Addins\G2MAddin.OutlookAddin"
    if( $OldPlugin -ne $null -and $OldPlugin.LoadBehavior -eq 3)
    {
        Write-Output "Disable the " + $OldPlugin.FriendlyName + " from automatic load on Outlook start"
        $OldPlugin | Set-ItemProperty -Name "LoadBehavior" -Value 2
    }
}
